bayespy.nodes.SwitchingGaussianMarkovChain.get_moments
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.get_moments